@@ -23,12 +23,12 @@ CONF = config.CONF
 
 
 class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
-
+    """Test creating servers on mutiple nodes with scheduler_hints."""
     @classmethod
     def resource_setup(cls):
         super(ServersOnMultiNodesTest, cls).resource_setup()
         cls.server01 = cls.create_test_server(wait_until='ACTIVE')['id']
-        cls.host01 = cls._get_host(cls.server01)
+        cls.host01 = cls.get_host_for_server(cls.server01)
 
     @classmethod
     def skip_checks(cls):
@@ -38,11 +38,6 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
             raise cls.skipException(
                 "Less than 2 compute nodes, skipping multi-nodes test.")
 
-    @classmethod
-    def _get_host(cls, server_id):
-        return cls.os_admin.servers_client.show_server(
-            server_id)['server']['OS-EXT-SRV-ATTR:host']
-
     def _create_servers_with_group(self, policy):
         group_id = self.create_test_server_group(policy=[policy])['id']
         hints = {'group': group_id}
@@ -61,7 +56,7 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         hosts = {}
         for server in servers:
             self.assertIn(server['id'], server_group['members'])
-            hosts[server['id']] = self._get_host(server['id'])
+            hosts[server['id']] = self.get_host_for_server(server['id'])
 
         return hosts
 
@@ -70,10 +65,11 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         compute.is_scheduler_filter_enabled("SameHostFilter"),
         'SameHostFilter is not available.')
     def test_create_servers_on_same_host(self):
+        """Test creating servers with hints 'same_host'"""
         hints = {'same_host': self.server01}
         server02 = self.create_test_server(scheduler_hints=hints,
                                            wait_until='ACTIVE')['id']
-        host02 = self._get_host(server02)
+        host02 = self.get_host_for_server(server02)
         self.assertEqual(self.host01, host02)
 
     @decorators.idempotent_id('cc7ca884-6e3e-42a3-a92f-c522fcf25e8e')
@@ -81,10 +77,11 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         compute.is_scheduler_filter_enabled("DifferentHostFilter"),
         'DifferentHostFilter is not available.')
     def test_create_servers_on_different_hosts(self):
+        """Test creating servers with hints of single 'different_host'"""
         hints = {'different_host': self.server01}
         server02 = self.create_test_server(scheduler_hints=hints,
                                            wait_until='ACTIVE')['id']
-        host02 = self._get_host(server02)
+        host02 = self.get_host_for_server(server02)
         self.assertNotEqual(self.host01, host02)
 
     @decorators.idempotent_id('7869cc84-d661-4e14-9f00-c18cdc89cf57')
@@ -92,11 +89,11 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         compute.is_scheduler_filter_enabled("DifferentHostFilter"),
         'DifferentHostFilter is not available.')
     def test_create_servers_on_different_hosts_with_list_of_servers(self):
-        # This scheduler-hint supports list of servers also.
+        """Test creating servers with hints of a list of 'different_host'"""
         hints = {'different_host': [self.server01]}
         server02 = self.create_test_server(scheduler_hints=hints,
                                            wait_until='ACTIVE')['id']
-        host02 = self._get_host(server02)
+        host02 = self.get_host_for_server(server02)
         self.assertNotEqual(self.host01, host02)
 
     @decorators.idempotent_id('f8bd0867-e459-45f5-ba53-59134552fe04')
@@ -110,7 +107,7 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         asserts the servers are in the group and on different hosts.
         """
         hosts = self._create_servers_with_group('anti-affinity')
-        hostnames = hosts.values()
+        hostnames = list(hosts.values())
         self.assertNotEqual(hostnames[0], hostnames[1],
                             'Servers are on the same host: %s' % hosts)
 
@@ -125,6 +122,6 @@ class ServersOnMultiNodesTest(base.BaseV2ComputeAdminTest):
         asserts the servers are in the group and on same host.
         """
         hosts = self._create_servers_with_group('affinity')
-        hostnames = hosts.values()
+        hostnames = list(hosts.values())
         self.assertEqual(hostnames[0], hostnames[1],
                          'Servers are on the different hosts: %s' % hosts)
